@@ -384,7 +384,7 @@ class CinacBenchmarks:
         else:
             self.colors_boxplots = colors_boxplots
 
-        self.colors_boxplots = self.colors_boxplots[::-1]
+        # self.colors_boxplots = self.colors_boxplots[::-1]
 
         # key is reference_id and value is a boolean, indicating if predictions are available for this inference
         # meaning values that give the probability for the cell to be active at a given frame
@@ -524,7 +524,7 @@ class CinacBenchmarks:
             return
 
         inference_to_benchmark = self.inferences_to_benchmark_dict[inference_to_benchmark_id][session_id]
-
+        # print(f"{session_id} {inference_to_benchmark_id}: n_cells for evaluation {len(inference_to_benchmark[0])}")
         raster_to_evaluate = inference_to_benchmark[0][cell]
         if len(inference_to_benchmark) == 2:
             raster_predictions = inference_to_benchmark[1][cell]
@@ -669,7 +669,7 @@ class CinacBenchmarks:
                                                    color=BREWER_COLORS[label_index % len(BREWER_COLORS)],
                                                    marker="o",
                                                    edgecolors=edgecolors,
-                                                   s=20, zorder=21, alpha=0.5)
+                                                   s=20, zorder=21, alpha=0.4)
 
                         else:
                             n_cells = 0
@@ -695,7 +695,7 @@ class CinacBenchmarks:
                                            color=BREWER_COLORS[0 % len(BREWER_COLORS)],
                                            marker="o",
                                            edgecolors=edgecolors,
-                                           s=20, zorder=21, alpha=0.5)
+                                           s=20, zorder=21, alpha=0.4)
 
                         outliers = dict(markerfacecolor='white', marker='D')
                         # if not for_frames:
@@ -723,7 +723,7 @@ class CinacBenchmarks:
                             if white_background:
                                 plt.setp(bplot[element], color="black")
                             else:
-                                plt.setp(bplot[element], color="silver")
+                                plt.setp(bplot[element], color="white")
 
                         if colorfull:
                             colors = self.colors_boxplots[:n_box_plots]
@@ -779,6 +779,7 @@ class CinacBenchmarks:
                     plt.close()
 
     def plot_boxplots_full_stat(self, description, time_str=None, for_frames=True, with_cells=False,
+                                color_cell_as_boxplot=False,
                                 box_plots_labels=None,
                                 colorfull=True,
                                 white_background=True,
@@ -852,7 +853,9 @@ class CinacBenchmarks:
                                 edgecolors = "black"
                             else:
                                 edgecolors = "white"
-                            if session_id not in self.cells_to_color:
+                            if color_cell_as_boxplot:
+                                color_cell = self.colors_boxplots[label_index%len(self.colors_boxplots)]
+                            elif session_id not in self.cells_to_color:
                                 color_cell = BREWER_COLORS[label_index % len(BREWER_COLORS)]
                             else:
                                 color_cell = self.cells_to_color[session_id]
@@ -860,7 +863,7 @@ class CinacBenchmarks:
                                        color=color_cell,
                                        marker="o",
                                        edgecolors=edgecolors,
-                                       s=60, zorder=21)
+                                       s=60, zorder=21, alpha=0.4)
                             if cell_to_display > 999:
                                 font_size = 2
                             ax.text(x=x_pos, y=y_pos,
@@ -889,10 +892,11 @@ class CinacBenchmarks:
                 if white_background:
                     plt.setp(bplot[element], color="black")
                 else:
-                    plt.setp(bplot[element], color="silver")
+                    plt.setp(bplot[element], color="white")
 
             if colorfull:
-                # supposing there are less box_plots than colors, but most probably there won't be more than 20 boxplots
+                # supposing there are less box_plots than colors,
+                # but most probably there won't be more than 20 boxplots
                 colors = self.colors_boxplots[:n_box_plots]
                 for patch, color in zip(bplot['boxes'], colors):
                     patch.set_facecolor(color)
@@ -1003,7 +1007,7 @@ class CinacBenchmarks:
                 plt.setp(bplot[element], color="white")
 
             for element in ['means', 'medians']:
-                plt.setp(bplot[element], color="silver")
+                plt.setp(bplot[element], color="white") # used to be silver
 
             if colorfull:
                 colors = colors[:n_box_plots]
@@ -1032,6 +1036,7 @@ class CinacBenchmarks:
 
     def plot_boxplots_f1_score(self, description, colorfull=False, time_str=None,
                                for_frames=True, with_cells=False,
+                               color_cell_as_boxplot=False,
                                box_plots_labels=None,
                                white_background=False,
                                save_formats="pdf", dpi=500):
@@ -1089,7 +1094,10 @@ class CinacBenchmarks:
                 for cell_to_display, stat_dict in cells_dict.items():
                     recall = stat_dict["sensitivity"]
                     precision = stat_dict["PPV"]
-                    f1_score = 2 * ((precision * recall) / (precision + recall))
+                    if (precision + recall) == 0:
+                        f1_score = 0
+                    else:
+                        f1_score = 2 * ((precision * recall) / (precision + recall))
                     values_by_prediction[label_index]. \
                         append(f1_score)
                     if with_cells:
@@ -1101,7 +1109,10 @@ class CinacBenchmarks:
                             edgecolors = "black"
                         else:
                             edgecolors = "white"
-                        if session_id not in self.cells_to_color:
+
+                        if color_cell_as_boxplot:
+                            color_cell = self.colors_boxplots[label_index % len(self.colors_boxplots)]
+                        elif session_id not in self.cells_to_color:
                             color_cell = BREWER_COLORS[label_index % len(BREWER_COLORS)]
                         else:
                             color_cell = self.cells_to_color[session_id]
@@ -1109,7 +1120,7 @@ class CinacBenchmarks:
                                    color=color_cell,
                                    marker="o",
                                    edgecolors=edgecolors,
-                                   s=60, zorder=21)
+                                   s=60, zorder=21, alpha=0.4)
                         ax.text(x=x_pos, y=y_pos,
                                 s=f"{cell_to_display}", color="black", zorder=22,
                                 ha='center', va="center", fontsize=font_size, fontweight='bold')
@@ -1134,7 +1145,7 @@ class CinacBenchmarks:
             if white_background:
                 plt.setp(bplot[element], color="black")
             else:
-                plt.setp(bplot[element], color="silver")
+                plt.setp(bplot[element], color="white") # "silver"
 
         if colorfull:
             colors = self.colors_boxplots[:n_box_plots]
@@ -1259,7 +1270,7 @@ class CinacBenchmarks:
                                        color=color_cell,
                                        marker="o",
                                        edgecolors=edgecolors,
-                                       s=60, zorder=21)
+                                       s=60, zorder=21, alpha=0.4)
                             if cell_to_display > 999:
                                 font_size = 2
                             if with_cell_text:
@@ -1287,7 +1298,7 @@ class CinacBenchmarks:
             if white_background:
                 plt.setp(bplot[element], color="black")
             else:
-                plt.setp(bplot[element], color="silver")
+                plt.setp(bplot[element], color="white") # silver
 
         if colorfull:
             colors = self.colors_boxplots[:n_box_plots]
@@ -1666,13 +1677,16 @@ def do_traces_smoothing(traces):
         traces[i] = smooth_signal[beg:-beg]
 
 
-def benchmark_neuronal_activity_inferences(inferences_dir, results_path):
+def benchmark_neuronal_activity_inferences(inferences_dir, results_path, colorfull_boxplots=True,
+    white_background=False, color_cell_as_boxplot=False):
     """
     Evaluate the performances of different inferences methods. Every directory in the main
     directory is considered a session with a ground truth and inferences to benchmark
     Args:
         inferences_dir: directory containing other directories, one by session to benchmark
         results_path:
+        colorfull_boxplots: if True boxplots are filled with color
+        white_background: if True background is white, else it's black
 
     Returns:
 
@@ -1743,9 +1757,6 @@ def benchmark_neuronal_activity_inferences(inferences_dir, results_path):
 
     time_str = datetime.now().strftime("%Y_%m_%d.%H-%M-%S")
 
-    colorfull_boxplots = True
-    white_background = False
-
     # ploting benchmarks
     # TODO: to fix, works for one prediction file only
     # cinac_benchmarks.plot_boxplot_predictions_stat_by_metrics(description=description, time_str=time_str,
@@ -1753,27 +1764,30 @@ def benchmark_neuronal_activity_inferences(inferences_dir, results_path):
     #                                                           white_background=white_background,
     #                                                           save_formats=["png"])
 
-    for for_frames in [True, False]:
+    # only transients
+    for for_frames in [False]:
         cinac_benchmarks.plot_boxplots_full_stat(description=description, time_str=time_str,
                                                  colorfull=colorfull_boxplots,
+                                                 color_cell_as_boxplot=color_cell_as_boxplot,
                                                  box_plots_labels=inferences_to_benchmark,
                                                  white_background=white_background,
-                                                 for_frames=for_frames, save_formats=["png"], with_cells=True, dpi=500)
+                                                 for_frames=for_frames, save_formats=["png"], with_cells=True, dpi=300)
 
         cinac_benchmarks.plot_boxplots_f1_score(description=description, time_str=time_str,
                                                 colorfull=colorfull_boxplots,
+                                                color_cell_as_boxplot=color_cell_as_boxplot,
                                                 box_plots_labels=inferences_to_benchmark,
                                                 white_background=white_background,
-                                                for_frames=for_frames, save_formats=["png"], with_cells=True, dpi=500)
+                                                for_frames=for_frames, save_formats=["png"], with_cells=True, dpi=300)
 
-    cinac_benchmarks.plot_boxplots_proportion_frames_in_transients(description=description,
-                                                                   time_str=time_str,
-                                                                   only_this_key=None,
-                                                                   colorfull=colorfull_boxplots,
-                                                                   white_background=white_background,
-                                                                   with_scatter=True,
-                                                                   with_cell_text=False,
-                                                                   save_formats="png", dpi=500)
+    # cinac_benchmarks.plot_boxplots_proportion_frames_in_transients(description=description,
+    #                                                                time_str=time_str,
+    #                                                                only_this_key=None,
+    #                                                                colorfull=colorfull_boxplots,
+    #                                                                white_background=white_background,
+    #                                                                with_scatter=True,
+    #                                                                with_cell_text=False,
+    #                                                                save_formats="png", dpi=300)
 
     # for inference_id in inference_ids:
     #     cinac_benchmarks.plot_boxplots_proportion_frames_in_transients(description=description,
