@@ -2,6 +2,11 @@ import h5py
 import numpy as np
 import os
 import yaml
+from ScanImageTiffReader import ScanImageTiffReader
+import time
+from PIL import ImageSequence
+import PIL
+import tifffile
 
 class CinacFileReader_open_close:
     # temporary version, to see if it would work better
@@ -1553,3 +1558,86 @@ class CinacFileReader:
                 else:
                     return np.array(group_data["doubtful_frames"])
         return None
+
+
+def create_tiffs_from_movie(path_for_tiffs, movie_identifier, movie_file_name=None, movie_data=None):
+    """
+    Take a Tiff movie or 3d array representing it, and save an unique tiff file for each of its frame.
+    Save as well the mean and std as npy file, all in the directory path_for_tiffs, in a directory with the
+    identifier
+    Args:
+        path_for_tiffs: str
+        movie_identifier: str
+        movie_file_name: str
+        movie_data: 3d array
+
+    Returns: boolean, return False if the directory with this identifier already exists, True if Tiffs have been
+    created
+
+    """
+
+    if movie_data is None and movie_file_name is None:
+       raise Exception("Movie_data or movie_file_name should not be None")
+
+    dir_names = []
+    # look for filenames in the fisrst directory, if we don't break, it will go through all directories
+    for (dirpath, dirnames, local_filenames) in os.walk(path_for_tiffs):
+        dir_names.extend([x.lower() for x in dirnames])
+        break
+
+    dir_found = False
+    for dir_name in dir_names:
+        if (movie_identifier.lower() in dir_name.lower()) or (dir_name.lower() in movie_identifier.lower()):
+            dir_found = True
+            break
+    if dir_found:
+        return False
+
+    print(f"create_tiffs_from_movie for {movie_identifier}")
+
+    if movie_data is None:
+        try:
+            start_time = time.time()
+            movie_data = ScanImageTiffReader(movie_file_name).data()
+            n_frames = len(movie_data)
+            stop_time = time.time()
+            print(f"Time for loading movie with scan_image_tiff: "
+                  f"{np.round(stop_time - start_time, 3)} s")
+        except Exception as e:
+            start_time = time.time()
+            im = PIL.Image.open(movie_file_name)
+            n_frames = len(list(ImageSequence.Iterator(im)))
+            dim_x, dim_y = np.array(im).shape
+            print(f"n_frames {n_frames}, dim_x {dim_x}, dim_y {dim_y}")
+            movie_data = np.zeros((n_frames, dim_x, dim_y), dtype="uint16")
+            for frame, page in enumerate(ImageSequence.Iterator(im)):
+                movie_data[frame] = np.array(page)
+            stop_time = time.time()
+            print(f"Time for loading movie: "
+                  f"{np.round(stop_time - start_time, 3)} s")
+    else:
+        n_frames = len(movie_data)
+
+    ms_path = os.path.join(path_for_tiffs, movie_identifier)
+    os.mkdir(ms_path)
+
+    # we can either save the file in 64 bits normalized
+    # or save it in 16 bits and then normalizing it using the mean and std values saved
+    # # normalizing movie
+    # tiff_movie = (tiff_movie - np.mean(tiff_movie)) / np.std(tiff_movie)
+
+    mean_value = np.mean(movie_data)
+    std_value = np.std(movie_data)
+
+    np.save(os.path.join(ms_path, "mean.npy"), mean_value)
+    np.save(os.path.join(ms_path, "std.npy"), std_value)
+
+    start_time = time.time()
+    # then saving each frame as a unique tiff
+    for frame in np.arange(n_frames):
+        tiff_file_name = os.path.join(ms_path, f"{frame}.tiff")
+        with tifffile.TiffWriter(tiff_file_name) as tiff:
+            tiff.save(movie_data[frame], compress=0)
+    stop_time = time.time()
+    print(f"Time for writing the tiffs: "
+          f"{np.round(stop_time - start_time, 3)} s")
