@@ -207,6 +207,7 @@ def check_one_dir_by_id_exists(identifiers, results_path, dir_in_id_name=False):
                     not_found = False
                     break
             if not_found:
+                print(f"check_one_dir_by_id_exists(): identifier {identifier} NOT FOUND in {results_path}")
                 return False
         else:
             if identifier.lower() not in dir_names:
@@ -535,7 +536,7 @@ def get_source_profile_param(cell, movie_dimensions, coord_obj, max_width, max_h
         len_x = max_height
         len_y = max_width
     else:
-        use_old_version = False
+        use_old_version = True
         if use_old_version:
             # calculating the bound that will surround all the cells
             minx = None
@@ -543,18 +544,37 @@ def get_source_profile_param(cell, movie_dimensions, coord_obj, max_width, max_h
             miny = None
             maxy = None
 
-            # if the size of the frame already matches the max dimensions, then we keep it that way
-            if (len_frame_y == max_width) and (len_frame_x == max_height):
-                minx = 0
-                miny = 0
-                maxx = max_height - 1
-                maxy = max_width - 1
+            centroid_cell = coord_obj.center_coord[cell]
+            min_x_centroid = int(centroid_cell[0]) - int(max_height // 2)
+            max_x_centroid = min_x_centroid + max_height - 1
+            min_y_centroid = int(centroid_cell[1]) - int(max_width // 2)
+            max_y_centroid = min_y_centroid + max_width - 1
+
+            poly_gon_cell = coord_obj.cells_polygon[cell]
+            minx_cell, miny_cell, maxx_cell, maxy_cell = np.array(list(poly_gon_cell.bounds)).astype(int)
+
+            # if the cell is bigger than the square, then we just put its centroid in the middle of it
+            if ((maxx_cell - minx_cell + 1) >= max_height) or \
+                    ((maxy_cell - miny_cell + 1) >= max_width):
+                minx = min_x_centroid
+                miny = min_y_centroid
+
+                # then we make sure we don't over go the border
+                minx = max(0, minx)
+                miny = max(0, miny)
+
+                # then we make sure we don't over go the border
+                if minx + max_height >= len_frame_x:
+                    minx = len_frame_x - max_height - 1
+                if miny + max_width >= len_frame_y:
+                    miny = len_frame_y - max_width - 1
+
+                maxx = minx + max_height - 1
+                maxy = miny + max_width - 1
+
                 len_x = max_height
                 len_y = max_width
             else:
-                centroid_cell = coord_obj.center_coord[cell]
-                min_x_centroid = int(centroid_cell[0]) - int(max_height // 2)
-                min_y_centroid = int(centroid_cell[1]) - int(max_width // 2)
 
                 for cell_in in cells_to_display:
                     poly_gon = coord_obj.cells_polygon[cell_in]
@@ -568,14 +588,34 @@ def get_source_profile_param(cell, movie_dimensions, coord_obj, max_width, max_h
                         maxx = max(maxx, tmp_maxx)
                         maxy = max(maxy, tmp_maxy)
 
-                # centering the window on the cell
-                if (min_x_centroid <= minx) and \
-                        ((min_x_centroid + max_height) >= maxx):
-                    minx = min_x_centroid
+                # # centering the window on the cell
+                # if (min_x_centroid <= minx) and \
+                #         ((min_x_centroid + max_height) >= maxx):
+                #     minx = min_x_centroid
+                #
+                # if (min_y_centroid <= miny) and \
+                #         ((min_y_centroid + max_width) >= maxy):
+                #     miny = min_y_centroid
 
-                if (min_y_centroid <= miny) and \
-                        ((min_y_centroid + max_width) >= maxy):
+                # trying to put the cell in, first by centering the frame around the centroid if necessary
+                # then if some part of the cell still are out, we use the min of the cell
+                if min_x_centroid < minx:
+                    minx = min_x_centroid
+                if minx_cell < minx:
+                    minx = minx_cell
+                if min_y_centroid < miny:
                     miny = min_y_centroid
+                if miny_cell < miny:
+                    miny = miny_cell
+
+                if (minx + max_height - 1) < max_x_centroid:
+                    minx = max_x_centroid - max_height + 1
+                if (minx + max_height - 1) < maxx_cell:
+                    minx = maxx_cell - max_height + 1
+                if (maxy + max_width - 1) < max_y_centroid:
+                    miny = max_y_centroid - max_width + 1
+                if (miny + max_width - 1) < maxy_cell:
+                    miny = maxy_cell - max_width + 1
 
                 # then we make sure we don't over go the border
                 minx = max(0, minx)
@@ -633,6 +673,8 @@ def get_source_profile_param(cell, movie_dimensions, coord_obj, max_width, max_h
                                         fill=fill_value)
 
         mask_dict[cell_to_display] = np.array(img)
+        # print(f"(minx, maxx, miny, maxy) {(minx, maxx, miny, maxy)}")
+        # print(f"im.shape {mask_dict[cell_to_display].shape}")
 
     if with_all_masks:
         return mask_dict, (minx, maxx, miny, maxy)
